@@ -1,6 +1,3 @@
-from xvg.core import Renderer
-
-
-class PNGRenderer(Renderer):
+class PNGRenderer():
     def __init__(self):
         raise NotImplementedError()
